View source: R/task_create_btw_md.R
| btw_task_create_btw_md | R Documentation |
Create a comprehensive context btw.md or AGENTS.md file for your project.
If launched in app or console mode, this task will start an interactive chat
session to guide you through the process of creating a context file.
This task focuses on documenting project context for developers and agents.
See btw_client() for additional details about the format and usage of the
btw.md context file, including choosing the default LLM provider and model
or the default set of tools to use with btw_client().
btw_task_create_btw_md(
...,
path = "btw.md",
client = NULL,
mode = c("app", "console", "client", "tool")
)
... |
Additional context to provide to the AI. This can be any text or
R objects that can be converted to text using |
path |
The path to the context file to create. Defaults to |
client |
An ellmer::Chat client or a |
mode |
The mode to run the task in, which affects what is returned from
this function. |
When mode is "app" or "console", this function launches an
interactive session in the browser or the R console, respectively. The
ellmer chat object with the conversation history is returned invisibly
when the session ends.
When mode is "client", this function returns the configured ellmer
chat client object. When mode is "tool", this function returns an
ellmer tool object that can be used in other chat instances.
Other task and agent functions:
btw_task_create_readme()
withr::with_envvar(list(ANTHROPIC_API_KEY = "example"), {
btw_task_create_btw_md(mode = "tool", client = "anthropic")
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.