View source: R/task_create_readme.R
| btw_task_create_readme | R Documentation |
Create a compelling, user-focused README file for your project. If launched in app or console mode, this task will start an interactive chat session to guide you through the process of creating a polished README that clearly communicates value and helps potential users make informed decisions.
This task focuses on creating READMEs for END USERS, not developers, with emphasis on clarity, accessibility, and authentic communication of value. The process involves exploring your project files, understanding your target audience and goals, proposing a structure, and then iteratively drafting each section with your input.
btw_task_create_readme(
...,
client = NULL,
mode = c("app", "console", "client", "tool")
)
... |
Additional context to provide to the AI. This can be any text or
R objects that can be converted to text using |
client |
An ellmer::Chat client or a |
mode |
The mode to run the task in, which affects what is returned from
this function. |
When mode is "app" or "console", this function launches an
interactive session in the browser or the R console, respectively. The
ellmer chat object with the conversation history is returned invisibly
when the session ends.
When mode is "client", this function returns the configured ellmer
chat client object. When mode is "tool", this function returns an
ellmer tool object that can be used in other chat instances.
Other task and agent functions:
btw_task_create_btw_md()
withr::with_envvar(list(ANTHROPIC_API_KEY = "example"), {
btw_task_create_readme(mode = "tool", client = "anthropic")
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.