View source: R/tool-data-frame.R
| btw_this.data.frame | R Documentation |
Describe a data frame in plain text
## S3 method for class 'data.frame'
btw_this(
x,
...,
format = c("skim", "glimpse", "print", "json"),
max_rows = 5,
max_cols = 100,
package = NULL
)
## S3 method for class 'tbl'
btw_this(
x,
...,
format = c("skim", "glimpse", "print", "json"),
max_rows = 5,
max_cols = 100,
package = NULL
)
x |
A data frame or tibble. |
... |
Additional arguments are silently ignored. |
format |
One of
|
max_rows |
The maximum number of rows to show in the data frame. Only
applies when |
max_cols |
The maximum number of columns to show in the data frame. Only
applies when |
package |
The name of the package that provides the data set. If not
provided, |
A character vector containing a representation of the data frame. Will error if the named data frame is not found in the environment.
btw_this(data.frame): Summarize a data frame.
btw_this(tbl): Summarize a tbl.
btw_tool_env_describe_data_frame()
Other btw formatting methods:
btw_this(),
btw_this.character(),
btw_this.environment()
Other btw formatting methods:
btw_this(),
btw_this.character(),
btw_this.environment()
btw_this(mtcars)
btw_this(mtcars, format = "print")
btw_this(mtcars, format = "json")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.