View source: R/tool-data-frame.R
| btw_tool_env_describe_data_frame | R Documentation |
Tool: Describe data frame
btw_tool_env_describe_data_frame(
data_frame,
format = c("skim", "glimpse", "print", "json"),
max_rows = 5,
max_cols = 100,
package = NULL,
`_intent` = ""
)
data_frame |
The data frame to describe |
format |
One of
|
max_rows |
The maximum number of rows to show in the data frame. Only
applies when |
max_cols |
The maximum number of columns to show in the data frame. Only
applies when |
package |
The name of the package that provides the data set. If not
provided, |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
A character vector containing a representation of the data frame. Will error if the named data frame is not found in the environment.
btw_this.data.frame(), btw_tools()
Other Tools:
btw_tool_docs_package_news(),
btw_tool_env_describe_environment(),
btw_tool_files_code_search(),
btw_tool_files_list_files(),
btw_tool_files_read_text_file(),
btw_tool_files_write_text_file(),
btw_tool_ide_read_current_editor(),
btw_tool_package_docs,
btw_tool_search_packages(),
btw_tool_session_package_info(),
btw_tool_session_platform_info(),
btw_tool_web_read_url(),
btw_tools()
btw_tool_env_describe_data_frame(mtcars)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.