View source: R/tool-environment.R
| btw_tool_env_describe_environment | R Documentation |
This tool can be used by the LLM to describe the contents of an R session, i.e. the data frames and other objects loaded into the global environment. This tool will only see variables that you've named and created in the global environment, it cannot reach into package namespaces, see which packages you have loaded, or access files on your computer.
btw_tool_env_describe_environment(items = NULL, `_intent` = "")
items |
Optional. A character vector of objects in the environment to describe. |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
A string describing the environment contents with #> prefixing
each object's printed representation.
btw_this.environment(), btw_tools()
Other Tools:
btw_tool_docs_package_news(),
btw_tool_env_describe_data_frame(),
btw_tool_files_code_search(),
btw_tool_files_list_files(),
btw_tool_files_read_text_file(),
btw_tool_files_write_text_file(),
btw_tool_ide_read_current_editor(),
btw_tool_package_docs,
btw_tool_search_packages(),
btw_tool_session_package_info(),
btw_tool_session_platform_info(),
btw_tool_web_read_url(),
btw_tools()
my_cars <- mtcars[mtcars$mpg > 25, ]
btw_tool_env_describe_environment("my_cars")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.