Path to a directory or file for which to get information. The
path must be in the current working directory. If path is a directory,
we use fs::dir_info() to list information about files and directories in
path (use type to pick only one or the other). If path is a file, we
show information about that file.
type
File type(s) to return, one of "any" or "file" or
"directory".
regexp
A regular expression (e.g. [.]csv$) passed on to grep() to filter paths.
_intent
An optional string describing the intent of the tool use.
When the tool is used by an LLM, the model will use this argument to
explain why it called the tool.
See Also
Other files tools:
btw_tool_files_edit(),
btw_tool_files_read(),
btw_tool_files_replace(),
btw_tool_files_search(),
btw_tool_files_write()