| btw_tool_files_write_text_file | R Documentation |
Tool: Write a text file
btw_tool_files_write_text_file(path, content, `_intent` = "")
path |
Path to the file to write. The |
content |
The text content to write to the file. This should be the complete content as the file will be overwritten. |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
Returns a message confirming the file was written.
Other Tools:
btw_tool_docs_package_news(),
btw_tool_env_describe_data_frame(),
btw_tool_env_describe_environment(),
btw_tool_files_code_search(),
btw_tool_files_list_files(),
btw_tool_files_read_text_file(),
btw_tool_ide_read_current_editor(),
btw_tool_package_docs,
btw_tool_search_packages(),
btw_tool_session_package_info(),
btw_tool_session_platform_info(),
btw_tool_web_read_url(),
btw_tools()
withr::with_tempdir({
btw_tool_files_write_text_file("example.txt", "Hello\nWorld!")
readLines("example.txt")
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.