| btw_tool_git_branch_create | R Documentation |
Allows an LLM to create a new git branch using gert::git_branch_create(),
equivalent to git branch <branch> in the terminal.
btw_tool_git_branch_create(
branch,
ref = "HEAD",
checkout = TRUE,
`_intent` = ""
)
branch |
Name of the new branch to create. |
ref |
Optional reference point for the new branch. Defaults to |
checkout |
Whether to check out the new branch after creation. Defaults
to |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
Returns a confirmation message.
Other git tools:
btw_tool_git_branch_checkout(),
btw_tool_git_branch_list(),
btw_tool_git_commit(),
btw_tool_git_diff(),
btw_tool_git_log(),
btw_tool_git_status()
withr::with_tempdir({
gert::git_init()
gert::git_config_set("user.name", "R Example")
gert::git_config_set("user.email", "ex@example.com")
fs::file_touch("hello.md")
gert::git_add("hello.md")
gert::git_commit("Initial commit")
# LLM creates a new branch
res <- btw_tool_git_branch_create(branch = "feature/new-analysis")
# What the LLM sees
cat(res@value)
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.