Learn R Programming

btw (version 1.2.0)

btw_tool_pkg_check: Tool: Run R CMD check on a package

Description

Run R CMD check on a package using devtools::check(). This performs comprehensive checks on the package structure, code, and documentation.

Usage

btw_tool_pkg_check(pkg = ".", `_intent` = "")

Value

The output from devtools::check().

Arguments

pkg

Path to package directory. Defaults to '.'. Must be within current working directory.

_intent

An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.

Details

The check runs with remote = TRUE, cran = TRUE, manual = FALSE, and error_on = "never" to provide comprehensive feedback without failing.

See Also

btw_tools()

Other pkg tools: btw_tool_pkg_coverage(), btw_tool_pkg_document(), btw_tool_pkg_load_all(), btw_tool_pkg_test()