Generate package documentation using devtools::document(). This runs
roxygen2 on the package to create/update man pages and NAMESPACE.
btw_tool_pkg_document(pkg = ".", `_intent` = "")The output from devtools::document().
Path to package directory. Defaults to ".". Must be within
current working directory.
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.
btw_tools()
Other pkg tools:
btw_tool_pkg_check(),
btw_tool_pkg_coverage(),
btw_tool_pkg_load_all(),
btw_tool_pkg_test()