Skip to contents

Load package code using pkgload::load_all() in a separate R process via callr::r(). This verifies that the package code loads without syntax errors and triggers recompilation of any compiled code (C, C++, etc.).

Usage

btw_tool_pkg_load_all(pkg = ".", `_intent` = "")

Arguments

pkg

Path to package directory. Defaults to '.'. Must be within current working directory.

_intent

An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.

Value

The output from pkgload::load_all().

Details

Important: This tool runs load_all() in an isolated R process and does NOT load the package code into your current R session. If you need to load the package code in your current session for interactive use, use the run R code tool to call pkgload::load_all() directly.