Run package tests using devtools::test(). Optionally filter tests by name
pattern.
btw_tool_pkg_test(pkg = ".", filter = NULL, `_intent` = "")The output from devtools::test().
Path to package directory. Defaults to '.'. Must be within current working directory.
Optional regex to filter test files. Example: 'helper' matches 'test-helper.R'.
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.
btw_tools()
Other pkg tools:
btw_tool_pkg_check(),
btw_tool_pkg_coverage(),
btw_tool_pkg_document(),
btw_tool_pkg_load_all()