btw_tool_search_package_info: Tool: Describe a CRAN package

View source: R/tool-search-packages.R

btw_tool_search_package_infoR Documentation

Tool: Describe a CRAN package

Description

Describes a CRAN package using pkgsearch::cran_package().

Usage

btw_tool_search_package_info(package_name, `_intent` = "")

Arguments

package_name

The name of a package on CRAN.

_intent

An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.

Value

An info sheet about the package.

Examples


cli::cat_line(
  btw_this(pkgsearch::cran_package("anyflights"))
)



btw documentation built on Nov. 5, 2025, 7:45 p.m.