btw_tool_session_platform_info: Tool: Describe user's platform

View source: R/tool-sessioninfo.R

btw_tool_session_platform_infoR Documentation

Tool: Describe user's platform

Description

Describes the R version, operating system, and language and locale settings for the user's system. When using btw_client() or btw_app(), this information is automatically included in the system prompt.

Usage

btw_tool_session_platform_info(`_intent` = "")

Arguments

_intent

An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.

Value

Returns a string describing the user's platform.

See Also

btw_tools()

Other Tools: btw_tool_docs_package_news(), btw_tool_env_describe_data_frame(), btw_tool_env_describe_environment(), btw_tool_files_code_search(), btw_tool_files_list_files(), btw_tool_files_read_text_file(), btw_tool_files_write_text_file(), btw_tool_ide_read_current_editor(), btw_tool_package_docs, btw_tool_search_packages(), btw_tool_session_package_info(), btw_tool_web_read_url(), btw_tools()

Examples

btw_tool_session_platform_info()


btw documentation built on Nov. 5, 2025, 7:45 p.m.