btw_tool_sessioninfo_package: Tool: Gather information about a package or currently loaded packages
Description
Uses sessioninfo::package_info() to provide information about the loaded,
attached, or installed packages. The primary use case is to verify that a
package is installed; check the version number of a specific packages; or
determine which packages are already in use in a session.
Returns a string describing the selected packages.
Arguments
packages
Which packages to show, or "loaded" to show all loaded
packages, "attached" to show all attached packages, or "installed" to
show all installed packages.
dependencies
Whether to include the dependencies when listing package
information.
_intent
An optional string describing the intent of the tool use.
When the tool is used by an LLM, the model will use this argument to
explain why it called the tool.
See Also
btw_tools(), btw_tool_sessioninfo_platform()
Other sessioninfo tools:
btw_tool_sessioninfo_is_package_installed(),
btw_tool_sessioninfo_platform()