Describes the R version, operating system, and language and locale settings
for the user's system. When using btw_client() or btw_app(), this
information is automatically included in the system prompt.
Usage
btw_tool_sessioninfo_platform(`_intent` = "")
Value
Returns a string describing the user's platform.
Arguments
_intent
An optional string describing the intent of the tool use.
When the tool is used by an LLM, the model will use this argument to
explain why it called the tool.
See Also
btw_tools()
Other sessioninfo tools:
btw_tool_sessioninfo_is_package_installed(),
btw_tool_sessioninfo_package()