| btw_tool_web_read_url | R Documentation |
Tool: Read a Web Page as Markdown
btw_tool_web_read_url(url, `_intent` = "")
url |
The URL of the web page to read. |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
You can control the maximum time to wait for the page to load by setting
the btw.max_wait_for_page_load_s option globally in your R session.
Returns a BtwWebPageResult object that inherits from
ellmer::ContentToolResult containing the markdown content of the web
page.
Other Tools:
btw_tool_docs_package_news(),
btw_tool_env_describe_data_frame(),
btw_tool_env_describe_environment(),
btw_tool_files_code_search(),
btw_tool_files_list_files(),
btw_tool_files_read_text_file(),
btw_tool_files_write_text_file(),
btw_tool_ide_read_current_editor(),
btw_tool_package_docs,
btw_tool_search_packages(),
btw_tool_session_package_info(),
btw_tool_session_platform_info(),
btw_tools()
btw_tool_web_read_url("https://www.r-project.org/")
btw_tool_web_read_url(
"https://posit.co/blog/easy-tool-calls-with-ellmer-and-chatlas/"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.