| btw_tools | R Documentation |
The btw_tools() function provides a list of tools that can be registered
with an ellmer chat via chat$set_tools() that allow the chat to
interface with your computational environment. Chats returned by
this function have access to the tools:
| Name | Description |
btw_tool_docs_available_vignettes() | List available vignettes for an R package. |
btw_tool_docs_help_page() | Get help page from package. |
btw_tool_docs_package_help_topics() | Get available help topics for an R package. |
btw_tool_docs_package_news() | Read the release notes (NEWS) for a package. |
btw_tool_docs_vignette() | Get a package vignette in plain text. |
| Name | Description |
btw_tool_env_describe_data_frame() | Show the data frame or table or get information about the structure of a data frame or table. |
btw_tool_env_describe_environment() | List and describe items in the R session's global environment. |
| Name | Description |
btw_tool_files_code_search() | Search code files in the project. |
btw_tool_files_list_files() | List files or directories in the project. |
btw_tool_files_read_text_file() | Read an entire text file. |
btw_tool_files_write_text_file() | Write content to a text file. |
| Name | Description |
btw_tool_git_branch_checkout() | Switch to a different git branch. |
btw_tool_git_branch_create() | Create a new git branch. |
btw_tool_git_branch_list() | List git branches in the repository. |
btw_tool_git_commit() | Stage files and create a git commit. |
btw_tool_git_diff() | View changes in the working directory or a commit. |
btw_tool_git_log() | Show the commit history for a repository. |
btw_tool_git_status() | Show the status of the git working directory. |
| Name | Description |
btw_tool_github() | Execute R code that calls the GitHub API using gh(). |
| Name | Description |
btw_tool_ide_read_current_editor() | Read the contents of the editor that is currently open in the user's IDE. |
| Name | Description |
btw_tool_search_package_info() | Describe a CRAN package. |
btw_tool_search_packages() | Search for an R package on CRAN. |
| Name | Description |
btw_tool_session_check_package_installed() | Check if a package is installed in the current session. |
btw_tool_session_package_info() | Verify that a specific package is installed, or find out which packages are in use in the current session. |
btw_tool_session_platform_info() | Describes the R version, operating system, language and locale settings for the user's system. |
| Name | Description |
btw_tool_web_read_url() | Read a web page and convert it to Markdown format. |
btw_tools(...)
... |
Optional names of tools or tool groups to include when registering
tools. By default all btw tools are included. For example, use The names provided can be:
|
Registers the tools with chat, updating the chat object in
place. The chat input is returned invisibly.
Other Tools:
btw_tool_docs_package_news(),
btw_tool_env_describe_data_frame(),
btw_tool_env_describe_environment(),
btw_tool_files_code_search(),
btw_tool_files_list_files(),
btw_tool_files_read_text_file(),
btw_tool_files_write_text_file(),
btw_tool_ide_read_current_editor(),
btw_tool_package_docs,
btw_tool_search_packages(),
btw_tool_session_package_info(),
btw_tool_session_platform_info(),
btw_tool_web_read_url()
# requires an ANTHROPIC_API_KEY
ch <- ellmer::chat_anthropic()
# register all of the available tools
ch$set_tools(btw_tools())
# or register only the tools related to fetching documentation
ch$set_tools(btw_tools("docs"))
# ensure that the current tools persist
ch$set_tools(c(ch$get_tools(), btw_tools()))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.