Lists the current CRAN version and archived package versions with their release dates. Archive dates are taken from CRAN's package archive index.
Arguments
- package_name
The name of a package on CRAN.
- after
Only return releases on or after this ISO date (
YYYY-MM-DD).- before
Only return releases on or before this ISO date (
YYYY-MM-DD).- _intent
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.
Value
A data frame with the version, release date and timestamp, current release status, and source tarball URL for each package release.
See also
Other cran tools:
btw_tool_cran_package(),
btw_tool_cran_search()