Tool: Edit a text file
btw_tool_files_edit(path, edits, `_intent` = "")Returns a message confirming the edits were applied.
Path to the file to edit. The path must be in the current
working directory.
A list of edit operations. Each edit is a named list with
action, line, and content fields.
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.
Other files tools:
btw_tool_files_list(),
btw_tool_files_read(),
btw_tool_files_replace(),
btw_tool_files_search(),
btw_tool_files_write()