Returns a character vector of lines from the file.
Arguments
path
Path to a file for which to get information. The path must be
in the current working directory.
line_start
Starting line to read, defaults to 1 (starting from the
first line).
line_end
Ending line to read, defaults to 1000. Change only this value
if you want to read more or fewer lines. Use in combination with
line_start to read a specific line range of the file.
_intent
An optional string describing the intent of the tool use.
When the tool is used by an LLM, the model will use this argument to
explain why it called the tool.
See Also
Other files tools:
btw_tool_files_edit(),
btw_tool_files_list(),
btw_tool_files_replace(),
btw_tool_files_search(),
btw_tool_files_write()