| btw_tool_git_branch_checkout | R Documentation |
Allows an LLM to switch to a different git branch using
gert::git_branch_checkout(), equivalent to git checkout <branch> in
the terminal.
btw_tool_git_branch_checkout(branch, force = FALSE, `_intent` = "")
branch |
Name of branch to check out. |
force |
Whether to force checkout even with uncommitted changes.
Defaults to |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
Returns a confirmation message.
Other git tools:
btw_tool_git_branch_create(),
btw_tool_git_branch_list(),
btw_tool_git_commit(),
btw_tool_git_diff(),
btw_tool_git_log(),
btw_tool_git_status()
withr::with_tempdir({
gert::git_init()
gert::git_config_set("user.name", "R Example")
gert::git_config_set("user.email", "ex@example.com")
fs::file_touch("hello.md")
gert::git_add("hello.md")
gert::git_commit("Initial commit")
gert::git_branch_create("feature-1")
# LLM checks out an existing branch
res <- btw_tool_git_branch_checkout(branch = "feature-1")
# What the LLM sees
cat(res@value)
})
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.