| btw_tool_package_docs | R Documentation |
These functions describe package documentation in plain text.
Show a list of available vignettes in the dplyr package:
btw_tool_docs_available_vignettes("dplyr")
Get the introductory vignette for the dplyr package:
btw_tool_docs_vignette("dplyr")
Get a specific vignette, such as the programming vignette for the dplyr
package:
btw_tool_docs_vignette("dplyr", "programming")
btw_tool_docs_package_help_topics(package_name, `_intent` = "")
btw_tool_docs_help_page(topic, package_name = "", `_intent` = "")
btw_tool_docs_available_vignettes(package_name, `_intent` = "")
btw_tool_docs_vignette(package_name, vignette = package_name, `_intent` = "")
package_name |
The name of the package as a string, e.g. |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
topic |
The |
vignette |
The name (or index) of the vignette to retrieve. Defaults to the "intro" vignette to the package (by the same rules as pkgdown.) |
btw_tool_docs_package_help_topics() returns the topic_id, title, and
aliases fields for every topic in a package's documentation as a
json-formatted string.
btw_tool_docs_help_page() returns the help-page for a package topic as a
string.
btw_tools()
Other Tools:
btw_tool_docs_package_news(),
btw_tool_env_describe_data_frame(),
btw_tool_env_describe_environment(),
btw_tool_files_code_search(),
btw_tool_files_list_files(),
btw_tool_files_read_text_file(),
btw_tool_files_write_text_file(),
btw_tool_ide_read_current_editor(),
btw_tool_search_packages(),
btw_tool_session_package_info(),
btw_tool_session_platform_info(),
btw_tool_web_read_url(),
btw_tools()
btw_tool_docs_package_help_topics("btw")
btw_tool_docs_help_page("btw", "btw")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.