Load package code using pkgload::load_all() in a separate R process via
callr::r(). This verifies that the package code loads without syntax errors
and triggers recompilation of any compiled code (C, C++, etc.).
Value
The output from pkgload::load_all().
Details
Important: This tool runs load_all() in an isolated R process and does
NOT load the package code into your current R session. If you need to load
the package code in your current session for interactive use, use the run R
code tool to call pkgload::load_all() directly.
See also
Other pkg tools:
btw_tool_pkg_check(),
btw_tool_pkg_coverage(),
btw_tool_pkg_document(),
btw_tool_pkg_test()