View source: R/tool-search-packages.R
| btw_tool_search_package_info | R Documentation |
Describes a CRAN package using pkgsearch::cran_package().
btw_tool_search_package_info(package_name, `_intent` = "")
package_name |
The name of a package on CRAN. |
_intent |
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool. |
An info sheet about the package.
cli::cat_line(
btw_this(pkgsearch::cran_package("anyflights"))
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.