Learn R Programming

btw (version 1.0.0)

btw_tool_search_package_info: Tool: Describe a CRAN package

Description

Describes a CRAN package using pkgsearch::cran_package().

Usage

btw_tool_search_package_info(package_name, `_intent` = "")

Value

An info sheet about the package.

Arguments

package_name

The name of a package on CRAN.

_intent

An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.

Examples

Run this code
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true")
cli::cat_line(
  btw_this(pkgsearch::cran_package("anyflights"))
)

}

Run the code above in your browser using DataLab