powered by
Describes a CRAN package using pkgsearch::cran_package().
pkgsearch::cran_package()
btw_tool_search_package_info(package_name, `_intent` = "")
An info sheet about the package.
The name of a package on CRAN.
An optional string describing the intent of the tool use. When the tool is used by an LLM, the model will use this argument to explain why it called the tool.
if (FALSE) { # identical(Sys.getenv("IN_PKGDOWN"), "true") cli::cat_line( btw_this(pkgsearch::cran_package("anyflights")) ) }
Run the code above in your browser using DataLab